@@ -1,20 +1,13 @@
  fluidPage(theme = 'zoo.css',
-
     fluidRow(column(12, align="center",
-
       column(3,align = "left",
-
         radioButtons("radio", label = h5("Correlation Type"), selected = 1,
-                     choices = list("Pearson" = 1, "Spearman" = 2,"PearSpear" = 3)
+                     choices = list("Pearson" = 1, "Spearman" = 2)
         )
         ),
-
       column(9,align = "center",
-
       selectInput("spectrum_list_stocsy_i","Which spectrum do you want to see?",file_names[], selectize = FALSE),
-
       p(strong("To perform STOCSY analysis, double click on the desired driver peak in the spectrum below."))
-
       )
     )
       ),
@@ -26,10 +19,21 @@
 
         fluidRow(
 
-          sliderInput("cutoff_stocsy_i", label = h5("Correlation Cutoff"), min = 0,
-                      max = 1, value = 0.9 , step= 0.01)
+
+          sliderInput("cutoff_stocsy_i", label = h5("Correlation Cutoff"), min = -1,
+                      max = 1, value = c(-0.9,0.9) , step= 0.01),
+                      bsTooltip("cutoff_stocsy_i", "Set the minimum correlation coefficients",
+                                "right", options = list(container = "body"))
         ),
 
+        fluidRow(
+          textInput("pv", "p-value", "0.05")
+                    ),
+
+        fluidRow(verbatimTextOutput("r_critical"),
+                                    bsTooltip("r_critical", "R critical is calculate based on t-Student table, for the chosen p-value.",
+                                              "right", options = list(container = "body"))),
+
         fluidRow(
 
           tags$button(id = "x2_stocsy_i",
@@ -104,12 +108,14 @@
                tags$button(id = "all_stocsy_i",
                            class = "btn action-button",
                            tags$img(src = "all.png",
-                           height = "35px", width = "40px")
-               ),
+                           height = "35px", width = "40px")),
+                           bsTooltip("all_stocsy_i", "Show all spectrum",
+                                     "right", options = list(container = "body")),
+             ),
 
              br()
 
-              )
+
         ),
 
 
